@@ -26,7 +26,7 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <getopt.h>
-#if defined(__linux__) || !defined(NANO_TINY)
+#ifdef __linux__
 #include <sys/ioctl.h>
 #endif
 #ifdef ENABLE_UTF8
@@ -339,7 +339,7 @@ void emergency_save(const char *filename)
 		fprintf(stderr, _("\nToo many .save files\n"));
 	else if (write_file(targetname, NULL, SPECIAL, OVERWRITE, NONOTES)) {
 		fprintf(stderr, _("\nBuffer written to %s\n"), targetname);
-#ifndef NANO_TINY
+#if !defined(NANO_TINY) && defined(HAVE_CHMOD) && defined(HAVE_CHOWN)
 		/* Try to chmod/chown the saved file to the values of the original file,
 		 * but ignore any failure as we are in a hurry to get out. */
 		if (openfile->statinfo) {
@@ -358,9 +358,9 @@ void emergency_save(const char *filename)
  * that were modified. */
 void die(const char *msg, ...)
 {
-	va_list ap;
 	openfilestruct *firstone = openfile;
 	static int stabs = 0;
+	va_list ap;
 
 	/* When dying for a second time, just give up. */
 	if (++stabs > 1)
@@ -670,8 +670,8 @@ void version(void)
 	printf(_(" GNU nano, version %s\n"), VERSION);
 #endif
 #ifndef NANO_TINY
-	printf(" (C) 1999-2011, 2013-2022 Free Software Foundation, Inc.\n");
-	printf(_(" (C) 2014-%s the contributors to nano\n"), "2022");
+	/* TRANSLATORS: The %s is the year of the latest release. */
+	printf(_(" (C) %s the Free Software Foundation and various contributors\n"), "2022");
 #endif
 	printf(_(" Compiled options:"));
 
@@ -894,10 +894,11 @@ void signal_init(void)
 	sigaction(SIGTERM, &deed, NULL);
 
 #ifndef NANO_TINY
+#ifdef SIGWINCH
 	/* Trap SIGWINCH because we want to handle window resizes. */
 	deed.sa_handler = handle_sigwinch;
 	sigaction(SIGWINCH, &deed, NULL);
-
+#endif
 #ifdef SIGTSTP
 	/* Prevent the suspend handler from getting interrupted. */
 	sigfillset(&deed.sa_mask);
@@ -998,11 +999,13 @@ void continue_nano(int signal)
 /* Block or unblock the SIGWINCH signal, depending on the blockit parameter. */
 void block_sigwinch(bool blockit)
 {
+#ifdef SIGWINCH
 	sigset_t winch;
 
 	sigemptyset(&winch);
 	sigaddset(&winch, SIGWINCH);
 	sigprocmask(blockit ? SIG_BLOCK : SIG_UNBLOCK, &winch, NULL);
+#endif
 
 #ifndef NANO_TINY
 	if (the_window_resized)
@@ -1733,13 +1736,11 @@ int main(int argc, char **argv)
 		{"speller", 1, NULL, 's'},
 #endif
 		{"saveonexit", 0, NULL, 't'},
-		{"tempfile", 0, NULL, 't'},  /* Deprecated; remove in 2022. */
 		{"view", 0, NULL, 'v'},
 #ifdef ENABLE_WRAPPING
 		{"nowrap", 0, NULL, 'w'},
 #endif
 		{"nohelp", 0, NULL, 'x'},
-		{"suspendable", 0, NULL, 'z'},  /* Obsolete; remove in 2022. */
 #ifndef NANO_TINY
 		{"smarthome", 0, NULL, 'A'},
 		{"backup", 0, NULL, 'B'},
@@ -1786,10 +1787,12 @@ int main(int argc, char **argv)
 	/* Back up the terminal settings so that they can be restored. */
 	tcgetattr(STDIN_FILENO, &original_state);
 
+#if defined(F_GETFL) && defined(F_SETFL)
 	/* Get the state of standard input and ensure it uses blocking mode. */
 	stdin_flags = fcntl(STDIN_FILENO, F_GETFL, 0);
 	if (stdin_flags != -1)
 		fcntl(STDIN_FILENO, F_SETFL, stdin_flags & ~O_NONBLOCK);
+#endif
 
 #ifdef ENABLE_UTF8
 	/* If setting the locale is successful and it uses UTF-8, we will
@@ -1813,7 +1816,7 @@ int main(int argc, char **argv)
 		SET(RESTRICTED);
 
 	while ((optchr = getopt_long(argc, argv, "0ABC:DEFGHIJ:KLMNOPQ:RST:UVWX:Y:Z"
-				"abcdef:ghijklmno:pqr:s:tuvwxyz$%_!", long_options, NULL)) != -1) {
+				"abcdef:ghijklmno:pqr:s:tuvwxy$%_!", long_options, NULL)) != -1) {
 		switch (optchr) {
 #ifndef NANO_TINY
 			case 'A':
@@ -2045,10 +2048,6 @@ int main(int argc, char **argv)
 			case 'y':
 				SET(AFTER_ENDS);
 				break;
-#endif
-			case 'z':
-				break;
-#ifndef NANO_TINY
 			case '%':
 				SET(STATEFLAGS);
 				break;
@@ -2072,7 +2071,7 @@ int main(int argc, char **argv)
 
 	/* Curses needs TERM; if it is unset, try falling back to a VT220. */
 	if (getenv("TERM") == NULL)
-		setenv("TERM", "vt220", 0);
+		putenv("TERM=vt220");
 
 	/* Enter into curses mode.  Abort if this fails. */
 	if (initscr() == NULL)
@@ -2082,6 +2081,9 @@ int main(int argc, char **argv)
 	/* If the terminal can do colors, tell ncurses to switch them on. */
 	if (has_colors())
 		start_color();
+
+	/* When requested, suppress the default spotlight and error colors. */
+	rescind_colors = (getenv("NO_COLOR") != NULL);
 #endif
 
 	/* Set up the function and shortcut lists.  This needs to be done
@@ -2558,7 +2560,7 @@ int main(int argc, char **argv)
 				edit_scroll(FORWARD);
 				wnoutrefresh(midwin);
 			}
-			wredrawln(footwin, 0 ,1);
+			wredrawln(footwin, 0, 1);
 			wnoutrefresh(footwin);
 			place_the_cursor();
 		} else if (ISSET(ZERO) && lastmessage > VACUUM)
